// verifyJarfile.js  version 0.1.5 By Eric Gerds
//
// This script will verify that your jarfile name & path are correct when
// using PluginDetect's Java detection.
//


/*     INSTRUCTIONS on how to use this verifyJarfile.js script

Step 1) Place this script in your web page immediately after the PluginDetect script.
  For example:

        <script type="text/javascript" src="PluginDetect.js"></script>
        <script type="text/javascript" src="verifyJarfile.js"></script>


Step 2) We assume here that your Java plugin detection code is already in your web page somewhere.
 If you do not have any detection code in the web page, then it is not possible to verify
 your jarfile.

Step 3) Load the web page in your browser. The verifyJarfile.js will place an output
  message at the top of your web page.

Step 4a) If the message at the top of your page says that the jarfile has been confirmed,
  then remove the verifyJarfile.js script from your web page.

Step 4b) If the message at the top of the page gives an error, then make sure the path of
  the jarfile is correct. The path must be relative to the webpage itself.


*/


// -----------------------------------------------------------------------------------------


// - Write instructions for this script
// - Make sure browser type is acceptable for this test
// - Unable to verify jarfile for Chrome 2.0 and < Opera 9.01
//     So some browsers obviously have problems

// DONE:
// - Have PluginDetect count the number of times that jarfile argument is used in detection code
// - Check is all the instances of jarfile arguments are exactly the same.
// - Make sure that Java is enabled
// - Make sure that ActiveX is enabled
// - Make sure that the verify script is only run ONCE
// - Check if user is only initiating Java from within $.onWindowLoaded()



if (typeof PluginDetect == 'undefined') PluginDetect = {};

if (typeof PluginDetect.verify == 'undefined') PluginDetect.verify = {
  $: PluginDetect,
  
  error: false,
  
  hasRun: false,
  
// Insert text node
//
// node = target of our text
// text = text content
// S = [style property, style value,...]
//
// br = 'false' will prevent line feed
addText: function(node, text, S, br){
     var N = typeof node == 'string' ? document.getElementById(node) : node;
     var N2 = N;
     if (N){

        if (S!=null && typeof S != 'undefined' && S.length > 0){
            var span = this.addSpan(N, S);
            N = span;
        };

        if (typeof text != 'undefined') N.appendChild(document.createTextNode(text));
        if (br===false){}
        else N2.appendChild(document.createElement('br'));
     };
},

thisScript: "verifyJarfile.js",


addSpan: function(node, S){
   var span = document.createElement('span'),
      style = span.style, x;

   if (typeof S != 'undefined'){
      for (x=0;x<S.length;x=x+2){
         style[S[x]] = S[x+1];
      };
   };
   node.appendChild(span);
   return span;
},


errorStyle: ['fontWeight', 'bold', 'color', '#CC4444'],
verifiedStyle: ['fontWeight', 'bold', 'color', 'blue'],


jar: function(){

  var $$ = this, 
    $ = $$.$, // PluginDetect
    output = document.createElement('div'),
    id1="plugindet221199", t=null;

    
  if (output.style) output.style.color = "#000000";
    
 
  if ($$.hasRun) return;
  $$.hasRun = true;  // prevent this routine from running twice


  output.id = 'outputverify';

  var style = output.style;
  style.border = "solid blue 2px";
  style.padding = "5px";
  style.width = "98%";
  style.margin = "5px";
  style.backgroundColor = "#B3AAAA";

  if (!document.body){
    document.write('<div id="' + id1 + '">o</div>');
    t = document.getElementById(id1);
  };

  if (document.body.firstChild &&
       typeof document.body.insertBefore != 'undefined')
            document.body.insertBefore(output, document.body.firstChild)
  else document.body.appendChild(output);

  if (t) t.parentNode.removeChild(t);
  
  
  var title = document.createElement('div');
  title.align = "center";
  output.appendChild(title);
  title.innerHTML = "<b>Jarfile Verification</b>";

  $$.addText(output);
  $$.addText(output, "This box is generated by a program called \"" + $$.thisScript +
    "\". It will verify that you correctly specified the jarfile [path/]name "+
    "in your Java detection code in this web page.");

  $$.addText(output);
  $$.addText(output, "Please keep in mind the following points:");

  $$.addText(output, "- When PluginDetect is able to detect Java without starting up the Java Runtime Environment, you do " +
     "not know whether your jarfile name/path were specified correctly. This Jarfile Verification test will force the " +
     "Java Runtime to start during plugin detection, thus showing if the jarfile was correctly specified.");
  $$.addText(output, "- An incorrectly specified jarfile will prevent Java detection from working in certain cases.");
  $$.addText(output, "- jarfile path is NOT allowed to contain backslash \"\\\". Use forwardslash \"/\" instead when needed.");
  $$.addText(output, "- Your jarfile only needs to be specified in the very first Java related PluginDetect " +
     "command that is executed.");
  $$.addText(output, "- Please make sure that Java is installed and enabled in your browser for " +
     "this verification test.");
  $$.addText(output, "- This jarfile verification test may not work on all browsers. " +
     "If it keeps giving you errors and you believe that your jarfile name/path are correct, " +
     "then try running this test on a different browser.");
  $$.addText(output, "- You do not need to run this verification test on all browsers. " +
     "You only need to pass this test on ONE browser.");

  $$.addText(output);
  $$.addText(output);

  $$.addText(output, "Verifying jarfile [path/]name in your Java detection code...");
  $$.addText(output);



  // Verify that PluginDetect has already been loaded
  if (typeof $.initScript == 'undefined'){
     $$.addText(output, "Error: Unable to find the PluginDetect script.", $$.errorStyle);
     $$.addText(output, "Make sure that the verify script is placed immediately AFTER the PluginDetect script in this web page.", $$.errorStyle);
     $$.error = true;
     $$.bye();
     return;
  };
  
  
  // Verify that PluginDetect java module exists
  if (typeof $.java == 'undefined'){
      $$.addText(output, "Error: your PluginDetect script cannot detect Java. Java module not present.", $$.errorStyle);
      $$.bye();
      return;
  };
  
  
  // Verify that PluginDetect version is compatible with this script
  if (typeof $.java.forceVerifyTag == 'undefined'){
      $$.addText(output, "Error: unable to verify jarfile with this version of PluginDetect.", $$.errorStyle);
      $$.addText(output, "Use a more current version of PluginDetect", $$.errorStyle);
      $$.bye();
      return;
  };

  // Find a way to force jarfile to always be used, so that we can test the jarfile.
  // Force verifyTags = [3,3,3]
  $.java.forceVerifyTag = [3,3,3];

  
  // verify that the user has not run any Java detection code yet
  if (typeof $.java.getVersionDone != 'undefined'){
      $$.addText(output, "Error: " + $$.thisScript + " must be placed somewhere IN BETWEEN the PluginDetect " +
         "script and your detection code.", $$.errorStyle);
      $$.addText(output, " ");
      $$.addText(output, "For example...");
      $$.addText(output, " ");
      $$.addText(output, "<head>");
      $$.addText(output, "<script type='text/javascript' src='PluginDetect.js'></script>");
      $$.addText(output, "<script type='text/javascript' src='" + $$.thisScript + "'></script>");
      $$.addText(output, "</head>");
      $$.addText(output, "<body>");
      $$.addText(output, "<script type='text/javascript'>");
      $$.addText(output, "var version = PluginDetect.getVersion('Java', 'getJavaInfo.jar');");
      $$.addText(output, "</script>");
      $$.addText(output, "</body>");

      $$.bye();
      return;
  };


  $$.winloadfn.verify212399 = true;

  // We wait until after the browser window has loaded.
  // Then we verify the jarfile integrity.
  if ($.onWindowLoaded) $.onWindowLoaded($$.winloadfn);
  
  else{
      var w = window.onload;
      window.onload = function(){
          $$.winloadfn($);
          if (typeof w=='function') w();
      };
  };


}, // end of jar()

// We verify jarfile only after window has loaded
// This routine is an event handler, it receives PluginDetect as input
winloadfn: function($){
        var $$ = $.verify, java = $.java, x, result, status, version;

        var output = document.getElementById('outputverify'), 
        
          warn1 = false;


        // verify that java getVersion routine was called at all
        // If it was not, then that means the user may have initiated AFTER window.onload
        if (typeof java.getVersionDone == 'undefined') warn1 = true;


        // find this function in the window.onload queue
        if ($.WLfuncs){
           var i=null;
           for (x=0;x<$.WLfuncs.length;x++){
                   if (typeof $.WLfuncs[x] == 'function' && $.WLfuncs[x].verify212399 === true){
                      i = x; break;
                   };
           };


           if (i!==null){   // found this function in the queue

                // execute all other functions after this one in the queue
                // This way, our function will execute AFTER the user's functions are all done.
                for (x=i+1;x<$.WLfuncs.length;x++){
                    $.call($.WLfuncs[x]); // Execute other functions in the window.onload queue
                    $.WLfuncs[x] = null;
                };

           };
        };


        if (typeof java.getVersionDone == 'undefined'){
              $$.addText(output,
                 "Error: You have not initiated any Java detection on this page. Unable to verify your jarfile.", $$.errorStyle);
              $$.bye();
              return;
        }



        if ($.onDetectionDone){ 
           $.onDetectionDone('Java', $$.detectInitiated);
           return
        };

          
        // If we get this far, then Java detection was initiated by the user

        $$.detectInitiated($);



},  // end of winloadfn()

bye: function(){
   var $$=this, $=$$.$;
   var output = document.getElementById('outputverify')
   
   $$.addText(output);
   $$.addText(output, "DONE", $$.verifiedStyle);
   $$.addText(output);
},

// This routine is an event handler
// It receives PluginDetect as input
detectInitiated: function($){
   var $$=$.verify;
   $$.detectInitiated1();
   $$.bye();
},


// If we get this far, then Java detection was initiated by the user
detectInitiated1: function(){

        var $$=this, $=$$.$, java = $.java, x, result, status, version;
        
        var output = document.getElementById('outputverify');

        if ($.isMinVersion){
           status = $.isMinVersion("Java", "0");
           $$.addText(output, 'PluginDetect.isMinVersion("Java", "0", jarfile): ' + status);
        };

        if ($.getVersion){
           version = $.getVersion("Java");
           $$.addText(output, 'PluginDetect.getVersion("Java", jarfile): ' + version);
        }
        

        $$.addText(output, 'navigator.javaEnabled(): ' + navigator.javaEnabled());
        if ($.isIE) $$.addText(output, 'ActiveX enabled: ' + $.ActiveXEnabled);
        $$.addText(output);


        // Specify number of times that jarfile was specified in the detection code;
        var numJars = $.java.jar.length, qq, err=false;
        $$.addText(output, "jarfile was specified " + numJars + " time" + (numJars>1?"s":"") +
           " in your Java detection code as follows:");
        for (x=0;x<numJars;x++){
            qq = $.java.jar[x];

            $$.addText(output, "jarfile [path/]name" + ": \"" + qq + "\"", null, false);
            if (typeof qq != "string"){
               $$.addText(output,' (Error: jarfile not a string)', $$.errorStyle);
               err=true;
               continue;
            };

            // Make sure that jarfile name has no backslashes, and ends in .jar
            if ((/[\\]/).test(qq)){
               $$.addText(output,' (Error: jarfile path may not have backslash \"\\\")', $$.errorStyle, false);
               err=true;
            };
            if (!(/\.jar\s*$/).test(qq)){
               $$.addText(output,' (Error: jarfile must have extension \".jar\")', $$.errorStyle, false);
               err=true;
            };
            $$.addText(output);
        };
        $$.addText(output);
        if (err) return;


        
        // If more than one jarfile specified, then make sure that they are all the same
        if (numJars>1){
           var tmp = $.java.jar[0], same=true;

           for (x=1;x<numJars;x++){
               if (tmp!==$.java.jar[x]){same=false;break;}
           };

           // Error, not all jarfile names are the same
           if (!same){
              $$.addText(output, "Error: all jarfile [path/]names " +
                "in your detection code should be the same.", $$.errorStyle);
              return;
           };

        };

        
        

        // Verify jarfile name
        if (java.OTF <1){
          $$.addText(output,
            "Error: Unable to find jarfile in your detection code or jarfile name is wrong.", $$.errorStyle);
          return;
        };

        
        // If we get his far, then Java detection WITH a jarfile was initiated by the user





        if (status == -1 && $.isChrome===true){
           $$.addText(output, "NOTE: Google Chrome browser will only work with Java 1,6,0,10 or higher.");
        };

        result=null;
        for (x=0;x<java.BridgeResult.length;x++){
              if ( $.num(java.BridgeResult[x][0]) ){result=true;break};
              
              // In case the PluginDetect script is not able to do NOTF, and the browser
              // can only do NOTF, we query the applet again just to be sure.
              $.java.query1Applet(x+java.Applet0Index);
              if ( $.num(java.BridgeResult[x][0]) ){result=true;break};
        };
        


        if (result===null){    // *** Unable to query jarfile applet ***

           if (!$.isIE && !navigator.javaEnabled()){
              $$.addText(output, "Error: Java may be disabled in your browser. " +
                   "Please enable it in your browser settings.", $$.errorStyle);
              $$.addText(output, "Also, make sure that Java is installed.", $$.errorStyle);
              $$.addText(output, "Error: Unable to verify jarfile at this time.", $$.errorStyle);
              return;
           };


           if ($.isIE){
             if (!$.ActiveXEnabled){         // ActiveX disabled
                $$.addText(output, "Error: ActiveX appears to be disabled in Internet Explorer. " +
                  "Please enable it in your browser settings.", $$.errorStyle);

             };
             if (!navigator.javaEnabled()){  // navigator.javaEnabled() is false
                $$.addText(output, "Error: navigator.javaEnabled() appears to be false in Internet Explorer. " +
                  "Please enable Java in your browser settings.", $$.errorStyle);

             };
             
             if (!$.ActiveXEnabled || !navigator.javaEnabled()){
                $$.addText(output, "Error: Unable to verify jarfile at this time.", $$.errorStyle);
                return;
             };

           };
           
           
           if (status == -1){   // Java not installed
              $$.addText(output,
                 "Error: Java not installed, or Java not enabled in browser, or " +
                    "jarfile name and path are incorrect.", $$.errorStyle);
              $$.addText(output, "Error: Unable to verify jarfile at this time.", $$.errorStyle);
              return;
           };


           // If we get this far, then Java appears to be installed
           if (status == -0.2){
              $$.addText(output, 
                 "Error: Java appears to be installed but PluginDetect is unable to query jarfile applet.", $$.errorStyle);
              $$.addText(output, "Make sure Java is enabled in your browser. " +
                 "Also make sure that jarfile name and path are correct.", $$.errorStyle);
              $$.addText(output, "Error: Unable to verify jarfile at this time.", $$.errorStyle);
              return;
           };

           // If java NOTF code is absent from the PluginDetect script, then it is also possible
           // that the browser in question REQUIRES NOTF in order to do detection.
           if ($.java && !$.java.NOTF){
              $$.addText(output,
                "Warning: Unable to verify jarfile. Because the PluginDetect script in this page does not appear to have " +
                "NOTF detection capabilities, it may be possible that this particular browser " + 
                "requires NOTF and for this reason we are unable to verify the jarfile. " +
                "You might try a different browser that can do Java detection OTF to see if verification is successful.", $$.errorStyle
              );
              $$.addText(output);
           };

           $$.addText(output,
              "Error: possible problem with jarfile. Make sure jarfile name and path are correct in your detection code.", $$.errorStyle);
           $$.addText(output, "Remember that the jarfile path is relative to the webpage itself.", $$.errorStyle);
           return;
        };


        // jarfile has been verified
        var jarVersion = $$.getJarVersion();
        
        if (jarVersion>=0){ 
           $$.addText(output, "jarfile version: " + jarVersion);
           $$.addText(output, "");
        };
        

        $$.addText(output, "jarfile [path/]name: VERIFIED", $$.verifiedStyle);
        $$.addText(output);
        $$.addText(output, "You may now remove " + $$.thisScript + " from this web page.");

},


// Get any instantiated applet
getApplet:function(){

   var $$=this, $=$$.$, java = $.java, BR = java.BridgeResult, x;

   for (x=0;x<BR.length;x++){
      if (BR[x][x]){
        return $.getObject(java.DOMobj[java.Applet0Index + x]);
      };
   };

   return null;


},


// Get the version of the getJavaInfo.jar
getJarVersion:function(){
  
   var $$=this, $=$$.$, java = $.java, applet = $$.getApplet(), e, t;

   if (applet){

      t = null;
      try{t = applet.getProp('java.version') + " "}    // add " " to convert to string
      catch(e){};
      if ($.num(t)) return 2; // getJavaInfo.jar v2 has been detected


      t = null;
      try{t = applet.getVersion() + " "}   // add " " to convert to string
      catch(e){};
      if ($.num(t)) return 1; // getJavaInfo.jar v1 has been detected
   
   };

   return -1; // No version has been detected

}


};     // end of $.verify object

if (!PluginDetect.verify.hasRun) PluginDetect.verify.jar();
if (PluginDetect.verify.error) PluginDetect = null;

